<link rel="icon"
      type="image/svg+xml"
      href="{{ url_for('favicons', path='favicon.svg').path }}" />
<link rel="icon"
      type="image/png"
      sizes="32x32"
      href="{{ url_for('favicons', path='favicon-32x32.png').path }}" />
<link rel="icon"
      type="image/png"
      sizes="16x16"
      href="{{ url_for('favicons', path='favicon-16x16.png').path }}" />
<link rel="apple-touch-icon"
      sizes="180x180"
      href="{{ url_for('favicons', path='apple-touch-icon.png').path }}" />
<link rel="manifest" href="{{ url_for('site_webmanifest').path }}" />
<link rel="mask-icon"
      href="{{ url_for('favicons', path='safari-pinned-tab.svg').path }}"
      color="#5b2333" />
<meta name="msapplication-TileColor" content="#5b2333" />
<meta name="theme-color" content="#ffffff" />
